<?php
/**
 *  {$view_path}
 *
 *  @author     {$author}
 *  @package    {$project_id}
 *  @version    $Id: skel.view_test.php 503 2008-04-25 04:06:08Z mumumu-org $
 */

/**
 *  {$forward_name}ӥ塼μ
 *
 *  @author     {$author}
 *  @access     public
 *  @package    {$project_id}
 */
class {$view_class}_TestCase extends Ethna_UnitTestCase
{
    /**
     *  @access private
     *  @var    string  ӥ塼̾
     */
    var $forward_name = '{$forward_name}';

    /**
     *    ƥȤν
     *
     *    @access public
     */
    function setUp()
    {
        $this->createPlainActionForm(); // եκ
        $this->createViewClass();       // ӥ塼κ
    }

    /**
     *    ƥȤθ
     *
     *    @access public
     */
    function tearDown()
    {
    }

    /**
     *  {$forward_name}Υץƥȥ
     *
     *  @access public
     */
    function test_viewSample()
    {
        /*
        // ե
        $this->af->set('id', 1);

        // {$forward_name}
        $this->vc->preforward();
        $this->assertNull($this->af->get('data'));
        */

        /**
         *  TODO: ƥȥ򵭽ҤƲ
         *  @see http://simpletest.org/en/first_test_tutorial.html
         *  @see http://simpletest.org/en/unit_test_documentation.html
         */
        $this->fail('No Test! write Test!');
    }
}
?>
